summaryrefslogtreecommitdiff
path: root/src/wasm-type.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/wasm-type.h')
-rw-r--r--src/wasm-type.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/wasm-type.h b/src/wasm-type.h
index f5cb0bbb0..bc6b25b34 100644
--- a/src/wasm-type.h
+++ b/src/wasm-type.h
@@ -368,9 +368,9 @@ public:
const Struct& getStruct() const;
Array getArray() const;
- // If there is a nontrivial (i.e. non-basic) nominal supertype, return it,
- // else an empty optional.
- std::optional<HeapType> getSuperType() const;
+ // If there is a nontrivial (i.e. non-basic, one that was declared by the
+ // module) nominal supertype, return it, else an empty optional.
+ std::optional<HeapType> getDeclaredSuperType() const;
// Return the depth of this heap type in the nominal type hierarchy, i.e. the
// number of supertypes in its supertype chain.